@@ -1,6 +1,6 @@
 /* Kernel crypto API AF_ALG Message Digest API
  *
- * Copyright (C) 2016 - 2021, Stephan Mueller <smueller@chronox.de>
+ * Copyright (C) 2016 - 2022, Stephan Mueller <smueller@chronox.de>
  *
  * License: see COPYING file in root directory
  *
@@ -21,20 +21,17 @@
 #include "internal.h"
 #include "kcapi.h"
 
-DSO_PUBLIC
 int kcapi_md_init(struct kcapi_handle **handle, const char *ciphername,
 		  uint32_t flags)
 {
 	return _kcapi_handle_init(handle, "hash", ciphername, flags);
 }
 
-DSO_PUBLIC
 void kcapi_md_destroy(struct kcapi_handle *handle)
 {
 	_kcapi_handle_destroy(handle);
 }
 
-DSO_PUBLIC
 int kcapi_md_setkey(struct kcapi_handle *handle,
 		    const uint8_t *key, uint32_t keylen)
 {
@@ -69,7 +66,6 @@ static inline ssize_t _kcapi_md_update(struct kcapi_handle *handle,
 	return 0;
 }
 
-DSO_PUBLIC
 ssize_t kcapi_md_update(struct kcapi_handle *handle,
 			const uint8_t *buffer, size_t len)
 {
@@ -133,7 +129,6 @@ int32_t orig_md_digest(struct kcapi_handle *handle,
 	return (int32_t)impl_md_digest(handle, in, inlen, out, outlen);
 }
 
-DSO_PUBLIC
 uint32_t kcapi_md_digestsize(struct kcapi_handle *handle)
 {
 	struct kcapi_handle_tfm *tfm = handle->tfm;
@@ -141,7 +136,6 @@ uint32_t kcapi_md_digestsize(struct kcapi_handle *handle)
 	return tfm->info.hash_digestsize;
 }
 
-DSO_PUBLIC
 uint32_t kcapi_md_blocksize(struct kcapi_handle *handle)
 {
 	struct kcapi_handle_tfm *tfm = handle->tfm;
@@ -236,6 +230,12 @@ int32_t orig_md_sha512(const uint8_t *in, uint32_t inlen,
 	return (int32_t)kcapi_md_conv_common("sha512", in, inlen, out, outlen);
 }
 
+ssize_t kcapi_md_sm3(const uint8_t *in, size_t inlen,
+		     uint8_t *out, size_t outlen)
+{
+	return kcapi_md_conv_common("sm3", in, inlen, out, outlen);
+}
+
 static inline ssize_t kcapi_md_mac_conv_common(const char *name,
 	const uint8_t *key, uint32_t keylen,
 	const uint8_t *in, size_t inlen, uint8_t *out, size_t outlen)
@@ -346,3 +346,11 @@ int32_t orig_md_hmac_sha512(const uint8_t *key, uint32_t keylen,
 	return (int32_t)kcapi_md_mac_conv_common("hmac(sha512)", key, keylen,
 						 in, inlen, out, outlen);
 }
+
+ssize_t kcapi_md_hmac_sm3(const uint8_t *key, uint32_t keylen,
+			  const uint8_t *in, size_t inlen,
+			  uint8_t *out, size_t outlen)
+{
+	return kcapi_md_mac_conv_common("hmac(sm3)", key, keylen, in, inlen,
+					out, outlen);
+}
