@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 - 2021, Stephan Mueller <smueller@chronox.de>
+ * Copyright (C) 2015 - 2022, Stephan Mueller <smueller@chronox.de>
  *
  * License: see LICENSE file in root directory
  *
@@ -95,24 +95,30 @@ static const struct cp_rng_tests testcases[] = {
 	{ "HMAC SHA-256 DRBG NOPR", "drbg_nopr_hmac_sha256", 32 },
 	{ "HMAC SHA-384 DRBG NOPR", "drbg_nopr_hmac_sha384", 48 },
 	{ "HMAC SHA-512 DRBG NOPR", "drbg_nopr_hmac_sha512", 64 },
+	{ "HMAC SM3 DRBG NOPR", "drbg_nopr_hmac_sm3", 32 },
 	{ "HMAC SHA-1 DRBG PR", "drbg_pr_hmac_sha1", 20 },
 	{ "HMAC SHA-256 DRBG PR", "drbg_pr_hmac_sha256", 32 },
 	{ "HMAC SHA-384 DRBG PR", "drbg_pr_hmac_sha384", 48 },
 	{ "HMAC SHA-512 DRBG PR", "drbg_pr_hmac_sha512", 64 },
+	{ "HMAC SM3 DRBG PR", "drbg_pr_hmac_sm3", 32 },
 	{ "Hash SHA-1 DRBG NOPR", "drbg_nopr_sha1", 20 },
 	{ "Hash SHA-256 DRBG NOPR", "drbg_nopr_sha256", 32 },
 	{ "Hash SHA-384 DRBG NOPR", "drbg_nopr_sha384", 48 },
 	{ "Hash SHA-512 DRBG NOPR", "drbg_nopr_sha512", 64 },
+	{ "Hash SM3 DRBG NOPR", "drbg_nopr_sm3", 32 },
 	{ "Hash SHA-1 DRBG PR", "drbg_pr_sha1", 20 },
 	{ "Hash SHA-256 DRBG PR", "drbg_pr_sha256", 32 },
 	{ "Hash SHA-384 DRBG PR", "drbg_pr_sha384", 48 },
 	{ "Hash SHA-512 DRBG PR", "drbg_pr_sha512", 64 },
+	{ "Hash SM3 DRBG PR", "drbg_pr_sm3", 32 },
 	{ "CTR AES-128 DRBG NOPR", "drbg_nopr_ctr_aes128", 16 },
 	{ "CTR AES-192 DRBG NOPR", "drbg_nopr_ctr_aes192", 16 },
 	{ "CTR AES-256 DRBG NOPR", "drbg_nopr_ctr_aes256", 16 },
 	{ "CTR AES-128 DRBG PR", "drbg_pr_ctr_aes128", 16 },
 	{ "CTR AES-192 DRBG PR", "drbg_pr_ctr_aes192", 16 },
 	{ "CTR AES-256 DRBG PR", "drbg_pr_ctr_aes256", 16 },
+	{ "CTR SM4 DRBG NOPR", "drbg_nopr_ctr_sm4", 16 },
+	{ "CTR SM4 DRBG PR", "drbg_pr_ctr_sm4", 16 },
 //	{ "ANSI X9.31", "ansi_cprng", 16 },
 //	{ "FIPS mode ANSI X9.31", "fips_ansi_cprng", 16 },
 };
