@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# Copyright (C) 2016 - 2021, Stephan Mueller <smueller@chronox.de>
+# Copyright (C) 2016 - 2022, Stephan Mueller <smueller@chronox.de>
 #
 # License: see LICENSE file in root directory
 #
@@ -121,7 +121,9 @@ if $(uname -m | grep -q "x86_64") && [ -z "$NO_32BIT_TEST" ]
 then
 	(
 		cd "$DIRNAME/.." && \
-		LDFLAGS=-m32 CFLAGS=-m32 ./configure $COMPILE_OPTS && \
+		LDFLAGS="-m32 $LDFLAGS" \
+		CFLAGS="-m32 $CFLAGS" \
+		./configure $COMPILE_OPTS && \
 		make
 	)
 	if [ $? -ne 0 ]
